package com.zbf.system.service.impl;

import cn.hutool.json.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zbf.common.core.domain.AjaxResult;
import com.zbf.system.domain.DeviceLog;
import com.zbf.system.mapper.DeviceLogMapper;
import com.zbf.system.service.IDeviceLogService;
import com.zbf.system.utils.DeviceInfo;
import com.zbf.system.utils.HttpUtils;
import com.zbf.system.utils.SignTool;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author tony
 * @date 2024-10-22
 */
@Service
public class DeviceLogServiceImpl extends ServiceImpl<DeviceLogMapper, DeviceLog> implements IDeviceLogService //修改
{
    @Autowired
    private DeviceLogMapper deviceLogMapper;

    /**
     * 推送
     * @param id 推送
     * @return
     */
    @Override
    public AjaxResult selectDeviceLogById(Long id)
    {
        DeviceLog deviceLog = deviceLogMapper.selectDeviceLogById(id);

        String sign = StringUtils.EMPTY;
        try {
            sign = SignTool.generateSign(DeviceInfo.AKSKID,DeviceInfo.AK,DeviceInfo.SK);
        } catch (Exception e) {
            e.printStackTrace();
        }

        Map<String,String> headers = new HashMap<>();
        headers.put("Content-Type", "application/json;charset=UTF-8");
        headers.put("Datalink-Sign",sign);
        headers.put("datalink-region","SA");

        String ip = "https://iepm.rzport.com:38443/datalinkprobackend/aksk/formentity/entityManagement/batchSaveEntity";
        JSONObject result = HttpUtils.post(ip, deviceLog.getObj(), headers);
        if (result.get("code").equals("1")) {
            deleteDeviceLogByIds(new Long[]{id});
            return AjaxResult.success("操作成功");
        }
        String msg = result.getStr("msg");
        return AjaxResult.error(msg);
    }

    /**
     * 查询【请填写功能名称】列表
     *
     * @param deviceLog 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<DeviceLog> selectDeviceLogList(DeviceLog deviceLog)
    {
        return deviceLogMapper.selectDeviceLogList(deviceLog);
    }

    /**
     * 新增【请填写功能名称】
     *
     * @param deviceLog 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertDeviceLog(DeviceLog deviceLog)
    {
        return deviceLogMapper.insertDeviceLog(deviceLog);
    }

    /**
     * 修改【请填写功能名称】
     *
     * @param deviceLog 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateDeviceLog(DeviceLog deviceLog)
    {
        return deviceLogMapper.updateDeviceLog(deviceLog);
    }

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteDeviceLogByIds(Long[] ids)
    {
        return deviceLogMapper.deleteDeviceLogByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteDeviceLogById(Long id)
    {
        return deviceLogMapper.deleteDeviceLogById(id);
    }


    /**
     * 批量禁用
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int disabledDeviceLogByIds(Long[] ids) {
        return deviceLogMapper.disabledDeviceLogByIds(ids);
    }

    /**
     * 批量启用
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int enableDeviceLogByIds(Long[] ids) {
        return deviceLogMapper.enableDeviceLogByIds(ids);
    }

    /**
     * 修改状态
     *
     * @param deviceLog 工序管理主键
     * @return 结果
     */
    @Override
    public int updateStatus(DeviceLog deviceLog) {
        return deviceLogMapper.updateDeviceLog(deviceLog);
    }

}
